<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format"
	xmlns:java="java" exclude-result-prefixes="fo">

	<xsl:output method="xml" version="1.0" omit-xml-declaration="no"
		indent="no" />

	<xsl:include href="template://Barcode_Template.xsl" />

	<!-- ============================== -->
	<!-- Template: Single Sticker -->
	<!-- ============================== -->

	<xsl:template match="sticker">

		<xsl:choose>
			<xsl:when test="/report/demo = 'true'">
				<fo:block background-image="url('image://FOP_DEMO')"
					background-position="0,0" background-repeat="repeat"
					background-color="white" padding="3mm">
					<xsl:call-template name="main_table"></xsl:call-template>
				</fo:block>
			</xsl:when>
			<xsl:otherwise>
				<fo:block padding="3mm">
					<xsl:call-template name="main_table"></xsl:call-template>
				</fo:block>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="main_table">
		<fo:table table-layout="auto" width="100%">
			<fo:table-column column-width="10mm" />
			<fo:table-column column-width="70mm" />
			<fo:table-column column-width="50mm" />
			<fo:table-body>

				<fo:table-row>

					<xsl:choose>
						<xsl:when test="printSmallLabels = 'true'">
							<fo:table-cell padding="1mm" padding-top="0mm"
								display-align="center">
								<fo:block>
									<xsl:call-template name="barcode">
										<xsl:with-param name="message" select="trackingCode" />
										<xsl:with-param name="codeType" select="'intl2of5'" />
										<xsl:with-param name="orientation" select="'-90'" />
										<xsl:with-param name="fontSize" select="'2.4mm'" />
										<xsl:with-param name="height" select="'6.5mm'" />
										<xsl:with-param name="moduleWidth" select="'0.21mm'" />
									</xsl:call-template>
								</fo:block>
								<fo:block font-size="3mm" color="white">
									<xsl:text>.</xsl:text>
								</fo:block>
								<fo:block>
									<xsl:call-template name="barcode">
										<xsl:with-param name="message" select="trackingCode" />
										<xsl:with-param name="codeType" select="'intl2of5'" />
										<xsl:with-param name="orientation" select="'-90'" />
										<xsl:with-param name="fontSize" select="'2.4mm'" />
										<xsl:with-param name="height" select="'6.5mm'" />
										<xsl:with-param name="moduleWidth" select="'0.21mm'" />
									</xsl:call-template>
								</fo:block>
							</fo:table-cell>
						</xsl:when>
						<xsl:otherwise>

							<fo:table-cell padding="1mm" padding-top="0mm">
								<xsl:choose>
									<xsl:when test="string-length(referenceNrBarcode) = 0">
										<fo:block>
											<xsl:text> </xsl:text>
										</fo:block>
									</xsl:when>
									<xsl:otherwise>
										<fo:block>
											<xsl:call-template name="barcode">
												<xsl:with-param name="message"
													select="substring(referenceNrBarcode, 1, 22)" />
												<xsl:with-param name="codeType" select="'code128'" />
												<xsl:with-param name="orientation" select="'-90'" />
												<xsl:with-param name="fontSize" select="'2.4mm'" />
												<xsl:with-param name="moduleWidth" select="'0.21mm'" />
												<xsl:with-param name="wideFactor" select="'2.2'" />
												<xsl:with-param name="height" select="'7.1mm'" />
											</xsl:call-template>
										</fo:block>
									</xsl:otherwise>
								</xsl:choose>
							</fo:table-cell>

						</xsl:otherwise>
					</xsl:choose>
					<fo:table-cell>

						<!-- Central column -->
						<fo:block padding="1mm" font-style="normal">
							<fo:table table-layout="auto" width="100%">
								<fo:table-body>
									<fo:table-row>
										<fo:table-cell>

											<!-- City logo -->
											<fo:block margin-bottom="1mm">
												<fo:table table-layout="auto" width="100%">
													<fo:table-body>
														<fo:table-row>
															<fo:table-cell>
																<fo:block font-size="5mm" font-weight="bold"
																	font-style="italic">
																	<xsl:value-of select="/report/licenseeInfo/name" />
																</fo:block>
															</fo:table-cell>
															<fo:table-cell>
																<fo:block>
																	<fo:table table-layout="auto" width="100%">
																		<fo:table-body>
																			<fo:table-row>
																				<fo:table-cell>
																					<fo:block font-size="3mm" text-align="right">
																						<xsl:value-of select="/report/licenseeInfo/phone" />
																					</fo:block>
																				</fo:table-cell>
																			</fo:table-row>
																			<fo:table-row>
																				<fo:table-cell>
																					<fo:block font-size="3mm" text-align="right"
																						font-style="italic">
																						<xsl:value-of select="/report/licenseeInfo/httpAddress" />
																					</fo:block>
																				</fo:table-cell>
																			</fo:table-row>
																		</fo:table-body>
																	</fo:table>
																</fo:block>
															</fo:table-cell>
														</fo:table-row>
													</fo:table-body>
												</fo:table>
											</fo:block>

											<!-- Sender box -->
											<fo:block font-size="3.5mm" border-style="solid"
												border-width="thin" padding="1mm" wrap-option="no-wrap"
												overflow="hidden">
												<fo:block font-size="3mm" font-style="italic">
													<xsl:value-of select="/report/shipmentSenderNameLabel" />
												</fo:block>
												<xsl:choose>
													<xsl:when test="printSenderLogo = 'true'">
														<fo:block text-align="center">
															<fo:inline>
																<fo:external-graphic width="70mm"
																	height="18mm" content-width="scale-to-fit"
																	content-height="scale-to-fit" src="url('logo://expedit')" />
															</fo:inline>
														</fo:block>
													</xsl:when>
													<xsl:otherwise>
														<fo:block text-align="center">
															<xsl:value-of select="sender/name" />
														</fo:block>
														<fo:block text-align="center">
															<xsl:value-of select="sender/address" />
														</fo:block>
														<fo:block text-align="center">
															<xsl:value-of select="sender/countryCode" />
															<xsl:text> </xsl:text>
															<xsl:value-of select="sender/postalCode" />
															<xsl:text>, </xsl:text>
															<xsl:value-of select="sender/city" />
														</fo:block>
														<xsl:choose>
															<xsl:when test="string-length(sender/phone) = 0">
																<fo:block font-size="3mm">
																	<xsl:text> </xsl:text>
																</fo:block>
															</xsl:when>
															<xsl:otherwise>
																<fo:block text-align="center" margin-left="0mm"
																	font-size="2.75mm">
																	<fo:inline padding-right="1mm">
																		<fo:external-graphic height="3mm"
																			content-width="scale-to-fit" src="url('image://FOP_ICON_PHONE')" />
																	</fo:inline>
																	<xsl:value-of select="sender/phone" />
																</fo:block>
															</xsl:otherwise>
														</xsl:choose>
													</xsl:otherwise>
												</xsl:choose>
											</fo:block>

											<!-- Barcode postal code -->
											<fo:block padding="0.1mm" text-align="center">
												<xsl:call-template name="barcode">
													<xsl:with-param name="message" select="receiver/postalCode" />
													<xsl:with-param name="codeType" select="'intl2of5'" />
													<xsl:with-param name="placement" select="'none'" />
												</xsl:call-template>
											</fo:block>

											<!-- Receiver box -->
											<fo:block font-size="3.5mm" border-style="solid"
												border-width="thin" padding="1mm" wrap-option="no-wrap"
												overflow="hidden">
												<fo:block font-size="3mm" font-style="italic">
													<xsl:value-of select="/report/shipmentReceiverNameLabel" />
												</fo:block>
												<fo:block text-align="center" wrap-option="wrap">
													<xsl:value-of select="receiver/name" />
												</fo:block>
												<fo:block text-align="center" wrap-option="wrap">
													<xsl:value-of select="receiver/address" />
												</fo:block>
												<fo:block text-align="center">
													<xsl:value-of select="receiver/countryCode" />
													<xsl:text> </xsl:text>
													<xsl:value-of select="receiver/postalCode" />
													<xsl:text>, </xsl:text>
													<xsl:value-of select="receiver/city" />
												</fo:block>
												<fo:block text-align="center" margin-left="0mm"
													font-size="2.75mm">
													<fo:inline padding-right="1mm">
														<fo:external-graphic height="3mm"
															content-width="scale-to-fit" src="url('image://FOP_ICON_PHONE')" />
													</fo:inline>
													<xsl:value-of select="receiver/phone" />
												</fo:block>
											</fo:block>

											<!-- Barcode multifunctional code -->
											<fo:block padding="0.1mm" text-align="center">
												<xsl:call-template name="barcode">
													<xsl:with-param name="message" select="multifunctionalCode" />
													<xsl:with-param name="placement" select="'none'" />
												</xsl:call-template>
											</fo:block>

											<!-- Contact person and sender -->
											<fo:block padding="0.5mm" wrap-option="no-wrap"
												overflow="hidden">
												<fo:table table-layout="auto" width="100%">
													<fo:table-body>
														<fo:table-row>
															<fo:table-cell>
																<fo:block font-size="2mm">
																	<xsl:value-of select="receiverContactPerson/label" />
																</fo:block>
															</fo:table-cell>
															<fo:table-cell>
																<fo:block font-size="2mm">
																	<xsl:value-of select="senderContactPerson/label" />
																</fo:block>
															</fo:table-cell>
														</fo:table-row>
														<fo:table-row>
															<fo:table-cell>
																<fo:block font-size="2.5mm">
																	<xsl:value-of select="receiverContactPerson/value" />
																</fo:block>
															</fo:table-cell>
															<fo:table-cell>
																<fo:block font-size="2.5mm">
																	<xsl:value-of select="senderContactPerson/value" />
																</fo:block>
															</fo:table-cell>
														</fo:table-row>
													</fo:table-body>
												</fo:table>
											</fo:block>

										</fo:table-cell>

									</fo:table-row>
								</fo:table-body>
							</fo:table>
						</fo:block>
					</fo:table-cell>

					<!-- Right column -->

					<fo:table-cell>

						<fo:block padding="1mm" margin="0" margin-left="1mm">
							<fo:table table-layout="auto" width="100%">
								<fo:table-body>
									<fo:table-row>
										<fo:table-cell>
											<fo:block margin-bottom="1.5mm" padding="0">
												<xsl:call-template name="barcode">
													<xsl:with-param name="message" select="trackingCode" />
													<xsl:with-param name="codeType" select="'intl2of5'" />
													<xsl:with-param name="fontSize" select="'4mm'" />
													<xsl:with-param name="height" select="'16.5mm'" />
												</xsl:call-template>
											</fo:block>
										</fo:table-cell>
									</fo:table-row>

									<fo:table-row>
										<fo:table-cell>
											<fo:block border-style="solid" border-width="thin"
												margin="0" margin-bottom="1.5mm" padding="0.5mm" font-size="2.7mm">
												<fo:table table-layout="auto" width="100%">
													<fo:table-column column-width="40%" />
													<fo:table-column column-width="60%" />
													<fo:table-body>
														<fo:table-row>
															<fo:table-cell padding="0.2mm">
																<fo:block>
																	<xsl:value-of select="date/label" />
																</fo:block>
															</fo:table-cell>
															<fo:table-cell padding="0.2mm">
																<fo:block>
																	<xsl:value-of select="date/value" />
																</fo:block>
															</fo:table-cell>
														</fo:table-row>
														<fo:table-row>
															<fo:table-cell padding="0.2mm">
																<fo:block>
																	<xsl:value-of select="weight/label" />
																</fo:block>
															</fo:table-cell>
															<fo:table-cell padding="0.2mm">
																<fo:block>
																	<xsl:value-of select="weight/value" />
																</fo:block>
															</fo:table-cell>
														</fo:table-row>
														<fo:table-row>
															<fo:table-cell padding="0.2mm">
																<fo:block>
																	<xsl:value-of select="referenceNr/label" />
																</fo:block>
															</fo:table-cell>
															<fo:table-cell padding="0.2mm">
																<fo:block wrap-option="wrap">
																	<xsl:call-template name="forcedWrapText">
																		<xsl:with-param name="data"
																			select="referenceNr/value" />
																	</xsl:call-template>
																</fo:block>
															</fo:table-cell>
														</fo:table-row>
													</fo:table-body>
												</fo:table>
											</fo:block>
										</fo:table-cell>
									</fo:table-row>

									<!-- <fo:table-row> <fo:table-cell> <fo:block margin="0" margin-bottom="2mm" 
										padding-left="0.5mm" font-size="2.5mm"> <xsl:value-of select="referenceNr/label" 
										/> <xsl:text>: </xsl:text> <fo:inline font-size="3mm"> <xsl:value-of select="referenceNr/value" 
										/> </fo:inline> </fo:block> </fo:table-cell> </fo:table-row> -->

									<fo:table-row>
										<fo:table-cell>
											<fo:block margin-top="2mm" margin-bottom="2mm">
												<fo:table table-layout="auto" width="100%">
													<fo:table-body>
														<fo:table-row>
															<fo:table-cell>
																<fo:block font-size="3mm">
																	<xsl:value-of select="servicesDescriptor/label" />
																</fo:block>
															</fo:table-cell>
														</fo:table-row>
														<fo:table-row>
															<fo:table-cell>
																<fo:block font-size="6mm">
																	<xsl:value-of select="servicesDescriptor/value" />
																</fo:block>
															</fo:table-cell>
														</fo:table-row>
													</fo:table-body>
												</fo:table>
											</fo:block>
										</fo:table-cell>
									</fo:table-row>

								</fo:table-body>
							</fo:table>
						</fo:block>

					</fo:table-cell>
				</fo:table-row>

				<!-- Footer -->
				<fo:table-row>
					<fo:table-cell>
						<fo:block></fo:block>
					</fo:table-cell>
					<fo:table-cell display-align="after">
						<fo:block font-size="2mm" font-style="italic">
							<xsl:value-of select="/report/licenseeInfo/shortDescription" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block font-size="3mm" text-align="right"
							padding-right="1mm">
							<xsl:value-of select="formattedPacketNumber" />
						</fo:block>
					</fo:table-cell>
				</fo:table-row>

			</fo:table-body>
		</fo:table>
	</xsl:template>

	<xsl:template name="separator_horizontal">
		<fo:block width="100%" height="1px">
			<fo:table table-layout="auto" width="100%" height="1px">
				<fo:table-body>
					<fo:table-row>
						<fo:table-cell width="10mm" height="0px" padding="0"
							border-top-style="solid" border-top-width="thin"
							border-top-color="#555555">
							<fo:block width="10mm" height="0px"></fo:block>
						</fo:table-cell>
						<fo:table-cell padding="0">
							<fo:block width="1px" height="1px"></fo:block>
						</fo:table-cell>
						<fo:table-cell width="10mm" height="0px" padding="0"
							border-top-style="solid" border-top-width="thin"
							border-top-color="#555555">
							<fo:block width="10mm" height="0px"></fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-body>
			</fo:table>
		</fo:block>
	</xsl:template>

	<xsl:template name="separator_vertical">
		<fo:block width="1px" height="97mm">
			<fo:table table-layout="auto" width="1px" height="97mm">
				<fo:table-body>
					<fo:table-row>
						<fo:table-cell width="0" height="10mm" padding="0"
							border-left-style="solid" border-left-width="thin"
							border-left-color="#555555">
							<fo:block width="0" height="0"></fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell width="0" height="71mm" padding="0">
							<fo:block width="1px" height="71mm"></fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell width="0" height="10mm" padding="0"
							border-left-style="solid" border-left-width="thin"
							border-left-color="#555555">
							<fo:block width="0" height="0"></fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell width="0" height="6mm" padding="0">
							<fo:block width="1px" height="6mm"></fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-body>
			</fo:table>
		</fo:block>
	</xsl:template>

	<xsl:template name="forcedWrapText">
		<xsl:param name="data" />
		<xsl:param name="counter" select="0" />
		<xsl:choose>
			<xsl:when test="$counter &lt;= string-length($data)">
				<xsl:value-of select='concat(substring($data,$counter,1),"​")' />
				<xsl:call-template name="internalForcedWrapText">
					<xsl:with-param name="data" select="$data" />
					<xsl:with-param name="counter" select="$counter+1" />
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="internalForcedWrapText">
		<xsl:param name="data" />
		<xsl:param name="counter" />
		<xsl:value-of select='concat(substring($data,$counter,1),"​")' />
		<xsl:call-template name="forcedWrapText">
			<xsl:with-param name="data" select="$data" />
			<xsl:with-param name="counter" select="$counter+1" />
		</xsl:call-template>
	</xsl:template>

</xsl:stylesheet>

