<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format"
	xmlns:java="java" exclude-result-prefixes="fo">

	<xsl:output method="xml" version="1.0" omit-xml-declaration="no"
		indent="no" />

	<xsl:param name="body.font.family" expression="Arial, FreeSans" />
	<xsl:param name="title.font.family" expression="Arial, FreeSans" />
	<xsl:param name="monospace.font.family" expression="Arial, FreeSans" />
	<!-- <xsl:param name="body.font.master" select="'10.1'" /> -->
	<xsl:param name="symbol.font.family" expression="Arial, FreeSans" />
	<xsl:param name="body.fontset" expression="Arial, FreeSans" />

	<!-- ========================================== -->
	<!-- Template: Delivery List Report A4 Portrait -->
	<!-- ========================================== -->

	<xsl:template match="report">
		<fo:root font-family="Arial, FreeSans">
			<fo:layout-master-set>
				<fo:simple-page-master master-name="whole_page"
					page-width="210mm" page-height="297mm" margin-top="10mm"
					margin-bottom="5mm" margin-left="10mm" margin-right="10mm">
					<xsl:choose>
						<xsl:when test="/report/demo = 'true'">
							<fo:region-body margin-left="0" margin-right="0"
								margin-top="15mm" margin-bottom="21mm" background-image="url('image://FOP_DEMO')"
								background-position="0,0" background-repeat="repeat"
								background-color="white" />
						</xsl:when>
						<xsl:otherwise>
							<fo:region-body margin-left="0" margin-right="0"
								margin-top="15mm" margin-bottom="21mm" />
						</xsl:otherwise>
					</xsl:choose>
					<fo:region-before extent="15mm" />
					<fo:region-after extent="10mm" />
				</fo:simple-page-master>
			</fo:layout-master-set>

			<fo:page-sequence master-reference="whole_page"
				initial-page-number="{/report/startingPageNumber}">

				<xsl:attribute-set name="headerCellWithBorderAttributeSet">
					<xsl:attribute name="border-style">solid</xsl:attribute>
					<xsl:attribute name="border-width">0</xsl:attribute>
					<xsl:attribute name="border-bottom-width">thin</xsl:attribute>
				</xsl:attribute-set>
				<xsl:attribute-set name="headerCellBlockAttributeSet">
					<xsl:attribute name="font-size">2.5mm</xsl:attribute>
					<xsl:attribute name="font-weight">normal</xsl:attribute>
					<xsl:attribute name="text-align">left</xsl:attribute>
					<xsl:attribute name="wrap-option">no-wrap</xsl:attribute>
					<xsl:attribute name="padding-top">2mm</xsl:attribute>
					<xsl:attribute name="padding-right">2mm</xsl:attribute>
					<xsl:attribute name="padding-bottom">0.5mm</xsl:attribute>
					<xsl:attribute name="padding-left">0</xsl:attribute>
				</xsl:attribute-set>
				<xsl:attribute-set name="headerCellBlockRightAttributeSet">
					<xsl:attribute name="font-size">2.5mm</xsl:attribute>
					<xsl:attribute name="font-weight">normal</xsl:attribute>
					<xsl:attribute name="text-align">right</xsl:attribute>
					<xsl:attribute name="wrap-option">no-wrap</xsl:attribute>
					<xsl:attribute name="padding-top">2mm</xsl:attribute>
					<xsl:attribute name="padding-right">2mm</xsl:attribute>
					<xsl:attribute name="padding-bottom">0.5mm</xsl:attribute>
					<xsl:attribute name="padding-left">0</xsl:attribute>
				</xsl:attribute-set>
				<fo:static-content flow-name="xsl-region-before">
					<fo:block font-weight="bold" text-align="center"
						wrap-option="no-wrap" padding-bottom="2mm">
						<xsl:value-of select="/report/lblDeliveryListReportTitle" />
					</fo:block>
					<!-- CityExpress signature -->
					<fo:block font-size="2.5mm" font-style="italic"
						text-align="center" wrap-option="no-wrap">
						<xsl:value-of select="/report/licenseeInfo/name" />
						<xsl:text>, </xsl:text>
						<xsl:value-of select="/report/licenseeInfo/postalCode" />
						<xsl:text> </xsl:text>
						<xsl:value-of select="/report/licenseeInfo/city" />
						<xsl:text>, </xsl:text>
						<xsl:value-of select="/report/licenseeInfo/address" />
					</fo:block>
				</fo:static-content>

				<fo:static-content flow-name="xsl-region-after">
					<!-- Footer begin -->
					<fo:block padding-top="1mm" border-style="solid"
						border-width="0" border-top-width="thin">
						<fo:table width="100%">
							<fo:table-body>
								<fo:table-row>
									<fo:table-cell>
										<fo:block font-size="2.5mm" text-align="left"
											wrap-option="no-wrap">
											<xsl:value-of select="/report/datum/label" />
											<xsl:text>: </xsl:text>
											<xsl:value-of select="/report/datum/value" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell>
										<fo:block font-size="2.5mm" text-align="center"
											font-style="italic" wrap-option="no-wrap">
											<xsl:value-of select="/report/expeditInfo/name" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell>
										<fo:block font-size="2.5mm" text-align="right"
											wrap-option="no-wrap">
											<xsl:value-of select="/report/lblPage" />
											<xsl:text> </xsl:text>
											<fo:page-number />
											<xsl:text> </xsl:text>
											<xsl:value-of select="/report/lblPageOf" />
											<xsl:text> </xsl:text>
											<fo:page-number-citation ref-id="endOfDocument" />
										</fo:block>
									</fo:table-cell>
								</fo:table-row>
							</fo:table-body>
						</fo:table>
					</fo:block>
					<!-- Footer end -->
				</fo:static-content>

				<fo:flow flow-name="xsl-region-body">
					<!-- Header begin -->
					<fo:block font-size="2.5mm" font-style="normal"
						margin-bottom="5mm">
						<fo:table width="100%">
							<fo:table-body>
								<fo:table-row>
									<fo:table-cell width="25mm"
										xsl:use-attribute-sets="headerCellWithBorderAttributeSet">
										<fo:block xsl:use-attribute-sets="headerCellBlockAttributeSet">
											<xsl:value-of select="/report/lblCourier" />
											<xsl:text>: </xsl:text>
										</fo:block>
									</fo:table-cell>
									<fo:table-cell width="50mm"
										xsl:use-attribute-sets="headerCellWithBorderAttributeSet">
										<fo:block xsl:use-attribute-sets="headerCellBlockAttributeSet">
											<xsl:text> </xsl:text>
										</fo:block>
									</fo:table-cell>
									<fo:table-cell>
										<fo:block xsl:use-attribute-sets="headerCellBlockRightAttributeSet">
											<xsl:text> </xsl:text>
										</fo:block>
									</fo:table-cell>
								</fo:table-row>
								<fo:table-row>
									<fo:table-cell xsl:use-attribute-sets="headerCellWithBorderAttributeSet">
										<fo:block xsl:use-attribute-sets="headerCellBlockAttributeSet">
											<xsl:value-of select="/report/lblRouteForDelivery" />
											<xsl:text>:</xsl:text>
										</fo:block>
									</fo:table-cell>
									<fo:table-cell xsl:use-attribute-sets="headerCellWithBorderAttributeSet">
										<fo:block xsl:use-attribute-sets="headerCellBlockAttributeSet">
											<xsl:text> </xsl:text>
										</fo:block>
									</fo:table-cell>
									<fo:table-cell>
										<fo:block xsl:use-attribute-sets="headerCellBlockRightAttributeSet"
											font-weight="bold">
											<xsl:value-of select="/report/weight/label" />
											<xsl:text>: </xsl:text>
											<xsl:value-of select="/report/weight/value" />
										</fo:block>
									</fo:table-cell>
								</fo:table-row>
								<fo:table-row>
									<fo:table-cell>
										<fo:block xsl:use-attribute-sets="headerCellBlockAttributeSet">
											<xsl:value-of select="/report/lblDeliveryListReportTitle" />
											<xsl:text>:</xsl:text>
										</fo:block>
									</fo:table-cell>
									<fo:table-cell>
										<fo:block xsl:use-attribute-sets="headerCellBlockAttributeSet">
											<xsl:value-of select="/report/lblDeliveryListReportReference" />
											<xsl:text> / </xsl:text>
											<xsl:value-of select="/report/numberOfShipments/value" />
											<xsl:text> </xsl:text>
											<xsl:value-of select="/report/lblPositions" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell>
										<fo:block xsl:use-attribute-sets="headerCellBlockRightAttributeSet">
											<xsl:value-of select="/report/numberOfShipments/label" />
											<xsl:text>: </xsl:text>
											<xsl:value-of select="/report/numberOfShipments/value" />
											<xsl:text> / </xsl:text>
											<xsl:value-of select="/report/numberOfParcels/value" />
											<xsl:text> </xsl:text>
											<xsl:value-of select="/report/lblNumberOfParcelsShort" />
										</fo:block>
									</fo:table-cell>
								</fo:table-row>
							</fo:table-body>
						</fo:table>
					</fo:block>
					<!-- Header end -->
					<fo:block>
						<fo:table width="100%" table-omit-header-at-break="false">
							<fo:table-header>
								<fo:table-row margin-bottom="10mm">
									<fo:table-cell border-style="solid" border-width="0"
										border-top-width="thin" border-bottom-width="thin" width="15mm">
										<fo:block font-size="2.5mm" font-weight="bold"
											text-align="left" padding-top="1mm" padding-bottom="1mm">
											<xsl:value-of select="/report/lblOrdinalNr" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell border-style="solid" border-width="0"
										border-top-width="thin" border-bottom-width="thin" width="30mm">
										<fo:block font-size="2.5mm" font-weight="bold"
											text-align="left" padding-top="1mm" padding-bottom="1mm">
											<xsl:value-of select="/report/lblReferenceNumbers" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell border-style="solid" border-width="0"
										border-top-width="thin" border-bottom-width="thin" width="25mm">
										<fo:block font-size="2.5mm" font-weight="bold"
											text-align="left" padding-top="1mm" padding-left="2mm"
											padding-bottom="1mm">
											<xsl:value-of select="/report/numberOfParcels/label" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell border-style="solid" border-width="0"
										border-top-width="thin" border-bottom-width="thin" width="30mm">
										<fo:block font-size="2.5mm" font-weight="bold"
											text-align="left" padding-top="1mm" padding-bottom="1mm">
											<xsl:text>Preuzimanje</xsl:text>
										</fo:block>
									</fo:table-cell>
									<fo:table-cell border-style="solid" border-width="0"
										border-top-width="thin" border-bottom-width="thin" width="25mm">
										<fo:block font-size="2.5mm" font-weight="bold"
											text-align="left" padding-top="1mm" padding-bottom="1mm">
											<xsl:value-of select="/report/lblParcelsNumbers" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell border-style="solid" border-width="0"
										border-top-width="thin" border-bottom-width="thin" width="20mm">
										<fo:block font-size="2.5mm" font-weight="bold"
											text-align="left" padding-top="1mm" padding-bottom="1mm">
											<xsl:value-of select="/report/weight/label" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell border-style="solid" border-width="0"
										border-top-width="thin" border-bottom-width="thin" width="20mm">
										<fo:block font-size="2.5mm" font-weight="bold"
											text-align="left" padding-top="1mm" padding-bottom="1mm">
											<xsl:value-of select="/report/lblServices" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell border-style="solid" border-width="0"
										border-top-width="thin" border-bottom-width="thin">
										<fo:block>
											<xsl:text> </xsl:text>
										</fo:block>
									</fo:table-cell>
								</fo:table-row>
							</fo:table-header>
							<fo:table-body>
								<!-- Main content begin -->
								<xsl:for-each select="shipmentsInfo/shipmentInfo">
									<xsl:apply-templates select="." />
								</xsl:for-each>
								<!-- Main content end -->
							</fo:table-body>
						</fo:table>
					</fo:block>
					<fo:block id="endOfDocument" />
				</fo:flow>

			</fo:page-sequence>
		</fo:root>
	</xsl:template>

	<xsl:template match="shipmentInfo">
		<fo:table-row keep-together.within-page="always">
			<fo:table-cell>
				<fo:block font-size="2.5mm" font-weight="bold" padding-top="1mm"
					padding-bottom="1mm">
					<xsl:value-of select="@ordinalNr" />
					<xsl:text>.</xsl:text>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell number-columns-spanned="7">
				<fo:block font-size="2.5mm" font-weight="bold" padding-top="1mm"
					padding-bottom="0.5mm">
					<xsl:value-of select="/report/lblReceiver" />
					<xsl:text>: </xsl:text>
					<xsl:value-of select="receiver/name" />
					<xsl:text>, </xsl:text>
					<xsl:value-of select="receiver/postalCode" />
					<xsl:text> </xsl:text>
					<xsl:value-of select="receiver/city" />
					<xsl:text>, </xsl:text>
					<xsl:value-of select="receiver/address" />
					<xsl:choose>
						<xsl:when test="string-length(receiverContactPerson) > 0">
							<xsl:text> (</xsl:text>
							<xsl:value-of select="/report/lblContactPersonShort" />
							<xsl:text>: </xsl:text>
							<xsl:value-of select="receiverContactPerson" />
							<xsl:text>)</xsl:text>
						</xsl:when>
					</xsl:choose>
				</fo:block>
				<fo:block font-size="2.5mm" font-weight="bold"
					padding-bottom="0.5mm">
					<xsl:value-of select="/report/lblSender" />
					<xsl:text>: </xsl:text>
					<xsl:value-of select="sender/name" />
					<xsl:text>, </xsl:text>
					<xsl:value-of select="sender/postalCode" />
					<xsl:text> </xsl:text>
					<xsl:value-of select="sender/city" />
					<xsl:text>, </xsl:text>
					<xsl:value-of select="sender/address" />
					<xsl:choose>
						<xsl:when test="string-length(senderContactPerson) > 0">
							<xsl:text> (</xsl:text>
							<xsl:value-of select="/report/lblContactPersonShort" />
							<xsl:text>: </xsl:text>
							<xsl:value-of select="senderContactPerson" />
							<xsl:text>)</xsl:text>
						</xsl:when>
					</xsl:choose>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
		<fo:table-row keep-with-previous.within-page="always">
			<fo:table-cell>
				<fo:block>
					<xsl:text> </xsl:text>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block font-size="2mm" text-align="left" padding-top="0.5mm"
					padding-bottom="0">
					<xsl:value-of select="/report/lblReferenceNr1" />
					<xsl:text>: </xsl:text>
					<xsl:value-of select="referenceNr1" />
				</fo:block>
				<fo:block font-size="2mm" text-align="left" padding-top="0.4mm"
					padding-bottom="0">
					<xsl:value-of select="/report/lblReferenceNr2" />
					<xsl:text>: </xsl:text>
					<xsl:value-of select="referenceNr2" />
				</fo:block>
				<fo:block font-size="2mm" text-align="left" padding-top="0.4mm"
					padding-bottom="1mm">
					<xsl:value-of select="/report/lblReferenceNr3" />
					<xsl:text>: </xsl:text>
					<xsl:value-of select="referenceNr3" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block font-size="2mm" text-align="left" padding-top="1mm"
					padding-bottom="1mm">
					<xsl:value-of select="numberOfParcels" />
					<xsl:text> </xsl:text>
					<xsl:value-of select="/report/lblNumberOfParcelsShort" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block font-size="2mm" text-align="left">
					<fo:table>
						<fo:table-body>
							<fo:table-row>
								<fo:table-cell width="7mm">
									<fo:block>
										<xsl:text>PR:</xsl:text>
									</fo:block>
								</fo:table-cell>
								<fo:table-cell border-style="solid" border-width="0"
									border-bottom-width="thin" width="13mm">
									<fo:block>
										<xsl:text> </xsl:text>
									</fo:block>
								</fo:table-cell>
							</fo:table-row>
							<fo:table-row>
								<fo:table-cell>
									<fo:block>
										<xsl:text>(pdv)</xsl:text>
									</fo:block>
								</fo:table-cell>
								<fo:table-cell border-style="solid" border-width="0"
									border-bottom-width="thin">
									<fo:block>
										<xsl:text> </xsl:text>
									</fo:block>
								</fo:table-cell>
							</fo:table-row>
							<fo:table-row>
								<fo:table-cell>
									<fo:block>
										<xsl:text>uklj.</xsl:text>
									</fo:block>
								</fo:table-cell>
								<fo:table-cell border-style="solid" border-width="0"
									border-bottom-width="thin">
									<fo:block>
										<xsl:text> </xsl:text>
									</fo:block>
								</fo:table-cell>
							</fo:table-row>
							<fo:table-row>
								<fo:table-cell border-style="solid" border-width="0"
									border-bottom-width="thin" padding-top="0.5mm">
									<fo:block>
										<xsl:text>CD</xsl:text>
									</fo:block>
								</fo:table-cell>
								<fo:table-cell border-style="solid" border-width="0"
									border-bottom-width="thin">
									<fo:block text-align="right" padding-top="0.5mm">
										<xsl:value-of select="cashOnDeliveryValue" />
									</fo:block>
								</fo:table-cell>
							</fo:table-row>
							<fo:table-row>
								<fo:table-cell>
									<fo:block padding-top="0.5mm" padding-bottom="0.5mm">
										<xsl:text>RSD</xsl:text>
									</fo:block>
								</fo:table-cell>
								<fo:table-cell>
									<fo:block>
										<xsl:text> </xsl:text>
									</fo:block>
								</fo:table-cell>
							</fo:table-row>
						</fo:table-body>
					</fo:table>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell wrap-option="wrap">
				<fo:block font-size="2mm" text-align="left" padding-top="1mm"
					padding-bottom="1mm">
					<xsl:for-each select="packetsInfo/packetsRow/packetCode">
						<xsl:value-of select="." />
						<xsl:text> </xsl:text>
					</xsl:for-each>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block font-size="2mm" text-align="left" padding-top="1mm"
					padding-bottom="1mm">
					<xsl:value-of select="weight" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell keep-together.within-column="always"
				wrap-option="wrap">
				<fo:block font-size="2mm" text-align="left" padding-top="1mm"
					padding-bottom="1mm">
					<xsl:value-of select="servicesDescriptor" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell wrap-option="wrap" display-align="after">
				<fo:block font-size="2mm" text-align="center" padding-top="0.5mm"
					padding-bottom="2mm" border-width="0" border-top-width="thin"
					border-style="dashed">
					<xsl:value-of select="/report/lblShipmentReceivedProperly" />
					<xsl:text> (</xsl:text>
					<xsl:value-of select="/report/datum/value" />
					<xsl:text>)</xsl:text>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
		<fo:table-row keep-with-previous.within-page="always">
			<fo:table-cell number-columns-spanned="8"
				border-bottom-style="solid" border-bottom-width="thin">
				<!-- CityExpress signature -->
				<fo:block font-size="2mm" text-align="center" wrap-option="no-wrap">
					<xsl:value-of select="/report/licenseeInfo/name" />
					<xsl:text>, </xsl:text>
					<xsl:value-of select="/report/licenseeInfo/postalCode" />
					<xsl:text> </xsl:text>
					<xsl:value-of select="/report/licenseeInfo/city" />
					<xsl:text>, </xsl:text>
					<xsl:value-of select="/report/licenseeInfo/address" />
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>

</xsl:stylesheet>

